@@ -321,12 +321,14 @@ class Scalene:
                 )
                 Scalene.update_line()
             Scalene.__last_profiled_invalidated = True
-            
+
             Scalene.__last_profiled = (
-                Filename("NADA"), LineNumber(0), ByteCodeIndex(0)
-            #     Filename(ff),
-            #     LineNumber(fl),
-            #     ByteCodeIndex(frame.f_lasti),
+                Filename("NADA"),
+                LineNumber(0),
+                ByteCodeIndex(0)
+                #     Filename(ff),
+                #     LineNumber(fl),
+                #     ByteCodeIndex(frame.f_lasti),
             )
             return None
         except AttributeError:
@@ -461,7 +463,7 @@ class Scalene:
         ],
         this_frame: Optional[FrameType],
     ) -> None:
-        """Handle allocation signals.""" 
+        """Handle allocation signals."""
         if this_frame:
             Scalene.enter_function_meta(this_frame, Scalene.__stats)
         # Walk the stack till we find a line of code in a file we are tracing.
@@ -487,9 +489,7 @@ class Scalene:
             and lineno == LineNumber(f.f_lineno)
         ):
             with Scalene.__invalidate_mutex:
-                Scalene.__invalidate_queue.append(
-                    (fname, lineno)
-                )
+                Scalene.__invalidate_queue.append((fname, lineno))
                 Scalene.update_line()
         Scalene.__last_profiled_invalidated = False
         Scalene.__last_profiled = (
@@ -683,10 +683,7 @@ class Scalene:
         atexit.register(Scalene.exit_handler)
         # Store relevant names (program, path).
         if program_being_profiled:
-            Scalene.__program_being_profiled = Filename(
-                # os.path.abspath(program_being_profiled)
-                program_being_profiled
-            )
+            Scalene.__program_being_profiled = Filename(program_being_profiled)
 
     @staticmethod
     def cpu_signal_handler(
@@ -757,7 +754,6 @@ class Scalene:
         # Restart the timer while handling any timers set by the client.
         if sys.platform != "win32":
             if Scalene.client_timer.is_set:
-
                 (
                     should_raise,
                     remaining_time,
@@ -1275,7 +1271,6 @@ class Scalene:
                 stats.memory_aggregate_footprint[last_file][
                     last_line
                 ] += stats.memory_current_highwater_mark[last_file][last_line]
-
                 stats.memory_current_footprint[last_file][last_line] = 0
                 stats.memory_current_highwater_mark[last_file][last_line] = 0
                 continue
@@ -1453,9 +1448,9 @@ class Scalene:
             prof in filename for prof in profile_exclude_list if prof != ""
         ):
             return False
-        if filename[0] == "<":
+        if filename[0] == "i":
             if (
-                "<ipython" not in filename
+                "ipython" not in filename
             ):  # lgtm [py/member-test-non-container]
                 # Not a real file and not a function created in Jupyter.
                 return False
@@ -1463,14 +1458,15 @@ class Scalene:
             # create a file to hold the contents.
             import IPython
 
-            if result := re.match("<ipython-input-([0-9]+)-.*>", filename):
+            if result := re.match("ipython-input-([0-9]+)-.*", filename):
                 # Write the cell's contents into the file.
+                cell_contents = (
+                    IPython.get_ipython().history_manager.input_hist_raw[
+                        int(result[1])
+                    ]
+                )
                 with open(filename, "w+") as f:
-                    f.write(
-                        IPython.get_ipython().history_manager.input_hist_raw[
-                            int(result[1])
-                        ]
-                    )
+                    f.write(cell_contents)
             return True
         # If (a) `profile-only` was used, and (b) the file matched
         # NONE of the provided patterns, don't profile it.
@@ -1709,13 +1705,12 @@ class Scalene:
                     os.chdir(os.path.join(webgui_dir, Scalene.__gui_dir))
                     t.start()
                     if Scalene.in_jupyter():
-                        from IPython.core.display import HTML, display
+                        from IPython.core.display import display
                         from IPython.display import IFrame
-
                         display(
                             IFrame(
                                 src=f"{Scalene.__localhost}:{PORT}/{Scalene.__profiler_html}",
-                                width=700,
+                                width="100%",
                                 height=600,
                             )
                         )
@@ -1840,7 +1835,7 @@ class Scalene:
                     raise FileNotFoundError
                 with open(progs[0], "rb") as prog_being_profiled:
                     # Read in the code and compile it.
-                    code: Any
+                    code: Any = ""
                     try:
                         code = compile(
                             prog_being_profiled.read(),
@@ -1921,7 +1916,8 @@ class Scalene:
                     # We are done with these files, so remove them.
                     Scalene.__malloc_mapfile.cleanup()
                     Scalene.__memcpy_mapfile.cleanup()
-            sys.exit(exit_status)
+            if not is_jupyter:
+                sys.exit(exit_status)
 
 
 if __name__ == "__main__":
